=======
nbutils
=======

Python notebook utils

Note:

    This project is still in beta stage, so the API is not finalized yet.

Contents:

.. toctree::
   :maxdepth: 2

   intro
   API <api>
   developer

* Web site: http://www.jdhp.org/software_en.html#nbutils
* Online documentation: http://nbutils.readthedocs.org
* Source code: https://github.com/jeremiedecock/python-nbutils
* Issue tracker: https://github.com/jeremiedecock/python-nbutils/issues
* nbutils on PyPI: https://pypi.python.org/pypi/nbutils

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Credits
=======

.. include:: ../AUTHORS
   :literal:

License
=======

.. highlight:: none

.. include:: ../LICENSE
   :literal:

